function addRollOutDialog(dialog, delay, easing, direction)
    --[[
    Create and setup temporary action for setting up the dialog,
    which will be called with startAction
    ]]
    local temp_action = game.CurrentScene:create(VSceneActions, 'rollout_action')
    --[[
    Create and setup temporary action part to mimick Start dialog one
    ]]
    local temp_actionpart = temp_action:create(VActionActionParts, 'rollout_actionpart')
    temp_actionpart.Command = 13 --Set START_DIALOG command
    temp_actionpart.Link = dialog --Set the action part link to the specified dialog
    --[[
    Print and tween the sprite to rollout based on the dialog's character dialog sprite
    ]]
    local sprite_path = dialog.Character.DialogSprite:getPath() --Get path of the dialog's character dialog sprite
    local sprite_position = dialog.Character.DialogSprite:getPosition() --Its position
    local sprite_size = dialog.Character.DialogSprite:getSize() --Its size
    local game_resolution = game.WindowResolution --And the game resolution, for offset calculations
    
    temp_sprite = graphics.loadFromFile(sprite_path)
    
    if direction == 0 then
        temp_sprite_position = { x = sprite_position.x, y = game_resolution.y } --Hides interface at window left
        sprite_hidden_position = { x = sprite_position.x, y = game_resolution.y } --Store original values for later use
        startTween('temp_sprite_position.y', temp_sprite_position.y, sprite_position.y, delay, easing) --Set rollout tween
    elseif direction == 1 then
        temp_sprite_position = { x = -sprite_size.x, y = sprite_position.y } --Hides interface at window left
        sprite_hidden_position = { x = -sprite_size.x, y = sprite_position.y }
        startTween('temp_sprite_position.x', temp_sprite_position.x, sprite_position.x, delay, easing)
    elseif direction == 2 then
        temp_sprite_position = { x = game_resolution.x, y = sprite_position.y } --Hides interface at window right
        sprite_hidden_position = { x = game_resolution.x, y = sprite_position.y }
        startTween('temp_sprite_position.x', temp_sprite_position.x, sprite_position.x, delay, easing)
    elseif direction == 3 then
        temp_sprite_position = { x = sprite_position.x, y = -sprite_size.y } --Hides interface at window top
        sprite_hidden_position = { x = sprite_position.x, y = -sprite_size.y }
        startTween('temp_sprite_position.y', temp_sprite_position.y, sprite_position.y, delay, easing)
    end
    
    game.HideCursor = true --Hides cursor while rollout effect so that can't keep clicking on things
    graphics.addDrawFunc('draw_temp_sprite()', 0) --Add the sprite draw function to the draw loop
    
    setDelay(delay, function() --Wait for the rollout effect to end
        startAction(temp_action) --Start dialog
        setDelay(50, function() --Wait a bit before giving back control
            temp_sprite_position.x = sprite_hidden_position.x --Return sprite to its hidden place
            temp_sprite_position.y = sprite_hidden_position.y
            game.HideCursor = false
        end)
    end)
end

function draw_temp_sprite()
    temp_sprite.position = { x = temp_sprite_position.x, y = temp_sprite_position.y }
    graphics.drawSprite(temp_sprite)
end

registerActionPart('DIALOG_ROLL_OUT',function(activeAction, actionPart)
	addRollOutDialog(actionPart.Link, actionPart.Int, actionPart.AltInt, actionPart.AltInt2)
	return false -- end of action
end)